/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.pns.transport.fcm;

/**
 * {@link FCMOptions} - The options to communicate with Google's Firebase Cloud Messaging (FCM).
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public class FCMOptions {

    private final String client;
    private final String keyPath;

    /**
     * Initialises a new {@link FCMOptions}.
     */
    public FCMOptions(String client, String keyPath) {
        super();
        this.client = client;
        this.keyPath = keyPath;
    }

    /**
     * Gets the client's name
     *
     * @return The client's name
     */
    public String getClient() {
        return client;
    }

    /**
     * Gets the keyPath
     *
     * @return The keyPath
     */
    public String getKeyPath() {
        return keyPath;
    }
}
